@@ -6,7 +6,7 @@
 use v5.26;
 use Object::Pad 0.70 ':experimental(adjust_params)';
 
-package Text::Treesitter 0.07;
+package Text::Treesitter 0.08;
 class Text::Treesitter
    :strict(params);
 
@@ -20,7 +20,17 @@ C<Text::Treesitter> - Perl binding for F<tree-sitter>
 
 =head1 SYNOPSIS
 
-   TODO
+   use Text::Treesitter;
+
+   my $ts = Text::Treesitter->new(
+      lang_name => "perl",
+   );
+
+   my $tree = $ts->parse_string( $input );
+
+   my $root = $tree->root_node;
+
+   ...
 
 =head1 DESCRIPTION
 
