@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2023 -- leonerd@leonerd.org.uk
 
-package Text::Treesitter::Language 0.07;
+package Text::Treesitter::Language 0.08;
 
 use v5.14;
 use warnings;
@@ -16,7 +16,16 @@ C<Text::Treesitter::Language> - represents a F<tree-sitter> language grammar
 
 =head1 SYNOPSIS
 
-   TODO
+Usually accessed indirectly, via C<Text::Treesitter>. Can also be used
+directly.
+
+   use Text::Treesitter::Language;
+
+   my $language_lib = "path/to/the/tree-sitter-perl.so";
+
+   my $lang = Text::Treesitter::Language::load( $language_lib, "perl" );
+
+   printf "This language defines %d symbols\n", $lang->symbol_count;
 
 =head1 DESCRIPTION
 
