@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2023 -- leonerd@leonerd.org.uk
 
-package Text::Treesitter::Query 0.07;
+package Text::Treesitter::Query 0.08;
 
 use v5.14;
 use warnings;
@@ -20,7 +20,17 @@ C<Text::Treesitter::Query> - represents a set of F<tree-sitter> query patterns
 
 =head1 SYNOPSIS
 
-   TODO
+Usually accessed indirectly, via C<Text::Treesitter>.
+
+   use Text::Treesitter;
+
+   my $ts = Text::Treesitter->new(
+      lang_name => "perl",
+   );
+
+   my $query = $ts->load_query_string( "path/to/query.scm" );
+
+   ...
 
 =head1 DESCRIPTION
 
