@@ -6,7 +6,7 @@
 use v5.26;
 use Object::Pad 0.73;
 
-package Text::Treesitter::QueryCursor 0.07;
+package Text::Treesitter::QueryCursor 0.08;
 class Text::Treesitter::QueryCursor
    :strict(params);
 
@@ -18,7 +18,22 @@ C<Text::Treesitter::QueryCursor> - stores the result of a F<tree-sitter> node qu
 
 =head1 SYNOPSIS
 
-   TODO
+   use Text::Treesitter;
+   use Text::Treesitter::QueryCursor;
+
+   my $ts = Text::Treesitter->new(
+      lang_name => "perl",
+   );
+
+   my $query = $ts->load_query_string( "path/to/query.scm" );
+
+   my $tree = $ts->parse_string( $input );
+
+   my $qc = Text::Treesitter::_QueryCursor->new;
+
+   $qc->exec( $query, $tree->root_node );
+
+   ...
 
 =head1 DESCRIPTION
 
