@@ -6,7 +6,7 @@
 use v5.26;
 use Object::Pad 0.70;
 
-package Text::Treesitter::QueryMatch 0.07;
+package Text::Treesitter::QueryMatch 0.08;
 class Text::Treesitter::QueryMatch
    :strict(params);
 
@@ -20,7 +20,36 @@ C<Text::Treesitter::QueryMatch> - stores the result of a F<tree-sitter> query pa
 
 =head1 SYNOPSIS
 
-   TODO
+Usually accessed indirectly, via C<Text::Treesitter::QueryCursor>.
+
+   use Text::Treesitter;
+   use Text::Treesitter::QueryCursor;
+
+   my $ts = Text::Treesitter->new(
+      lang_name => "perl",
+   );
+
+   my $query = $ts->load_query_string( "path/to/query.scm" );
+
+   my $tree = $ts->parse_string( $input );
+
+   my $qc = Text::Treesitter::_QueryCursor->new;
+
+   $qc->exec( $query, $tree->root_node );
+
+   while( my $match = $qc->next_match ) {
+      my @captures = $match->captures;
+
+      next unless $query->test_predicates_for_match( $tree, $match, \@captures );
+
+      foreach my $capture ( @captures ) {
+         my $node = $capture->node;
+         my $capturename = $query->capture_name_for_id( $capture->capture_id );
+
+         printf "%s captures the text <%s>\n",
+            $capturename, $node->text;
+      }
+   }
 
 =head1 DESCRIPTION
 
